3. API reference — PyPAGO 1.0.1 documentation

# 3. API reference

## 3.1. Classes

`pypago.sections.Section`(name, lon, lat, dire) | Section endpoint object.
`pypago.sections.GridSection`(grid, section) | Gridded section object

## 3.2. Processing model grid

`pypago.coords.create_coord`(modelname, filename) | Returns a Coord object, depending on the modelname
`pypago.grid.create_grid`(coord[, jmin, jmax, …]) | Returns a Grid instance associated with the input coord argument.
`pypago.sections.extract_grid_sections`(grid, …) | Extract a list of GridSection objects from a grid object (containing coordinates and scale factors) and a list of section endpoints.

## 3.3. Input/Output

`pypago.pyio.save`(dictio, filename) | Function that saves a variable object into a file.
`pypago.pyio.load`(filename) | Loads a file and reads its content.
`pypago.pyio.read_time`(filename, time_varname) | Reads the time variable of a NetCDF time.

## 3.4. NetCDF conversion

`pypago.nc` | Module that contains various functions dedicated to the conversion of PyPAGO outputs into NetCDF files` to `.nc` files

## 3.5. Loading data

`pypago.data.loaddata_sec_t`(model_sections, …) | Extracts the model output from model T-grid points and interpolates them on section west and north faces.
`pypago.data.loaddata_sec_uv`(model_sections, …) | Extracts the model output, interpolates if needed on west and north faces, and saves only the data along preselected sections and areas in structfile.
`pypago.data.loaddata_sec_uv_roms`(…) | Extracts the model output, interpolates if needed on west and north faces, and saves only the data along preselected sections and areas in structfile.
`pypago.data.loaddata_area_t`(model_areas, …) | Extracts the model output from model T-grid points and interpolates them on section west and north faces.

## 3.6. Miscellaneous

`pypago.misc.findsecnum`(model_sections, …) | Determines the index of a section in a list of sections
`pypago.misc.finddomnum`(model_areas, areaplotname) | Determines the index of a domain in a list of domains

## 3.7. Scientific calculations

`pypago.secdiag` | Module that handles transport calculation across gridded sections
`pypago.areadiag` | Module that handles domain calculation into domains

## 3.8. Plotting

`pypago.plot.plot_dom_mask`(grid[, gridsec, …]) | Draws the final plot.
`pypago.plot.pcolplot`(secstruct, vartoplot, …) | Pcolor of a variable contained in a gridded section.
`pypago.plot.contourplot`(secstruct, …[, …]) | Contourplot of a variable contained in a gridded section.